==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/keys/KeyRegistry.java <==
package net.inventive_mods.inventive_inventory.keys;

import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import org.jetbrains.annotations.Nullable;

public class KeyRegistry {
    public static final String INVENTIVE_INVENTORY_CATEGORY = "key.category.inventive_inventory.main";
    public static final String INVENTIVE_INVENTORY_PROFILES_CATEGORY = "key.category.inventive_inventory.profiles";
    public static final class_304[] profileKeys = new class_304[3];
    private static final String KEY_SORT = "key.inventive_inventory.sort";
    private static final String KEY_ADVANCED_OPERATION = "key.inventive_inventory.advanced_operation";
    private static final String KEY_OPEN_PROFILES_SCREEN = "key.inventive_inventory.open_profiles_screen";
    private static final String KEY_LOAD_PROFILE = "key.inventive_inventory.load_profile";
    public static class_304 sortKey;
    public static class_304 advancedOperationKey;
    public static class_304 openProfilesScreenKey;
    public static class_304 loadProfileKey;

    public static void register() {
        sortKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_SORT,
                class_3675.class_307.field_1668,
                class_3675.field_31907,
                INVENTIVE_INVENTORY_CATEGORY
        ));
        advancedOperationKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_ADVANCED_OPERATION,
                class_3675.class_307.field_1668,
                class_3675.field_31949,
                INVENTIVE_INVENTORY_CATEGORY
        ));
        openProfilesScreenKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_OPEN_PROFILES_SCREEN,
                class_3675.class_307.field_1668,
                class_3675.field_31911,
                INVENTIVE_INVENTORY_PROFILES_CATEGORY
        ));
        loadProfileKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_LOAD_PROFILE,
                class_3675.class_307.field_1668,
                class_3675.field_31949,
                INVENTIVE_INVENTORY_PROFILES_CATEGORY
        ));
        for (int i = 0; i < profileKeys.length; i++) {
            profileKeys[i] = KeyBindingHelper.registerKeyBinding(new class_304(
                    "key.inventive_inventory.profile_" + i,
                    class_3675.class_307.field_1668,
                    class_3675.field_31985 + i,
                    INVENTIVE_INVENTORY_PROFILES_CATEGORY
            ));
        }
    }

    @Nullable
    public static class_304 getByTranslationKey(String translationKey) {
        for (class_304 keyBinding : InventiveInventory.getClient().field_1690.field_1839) {
            if (keyBinding.method_1431().equals(translationKey)) return keyBinding;
        }
        return null;
    }

    @Nullable
    public static class_304 getByBoundKey(String boundKey) {
        for (class_304 keyBinding : profileKeys) {
            if (keyBinding.method_16007().getString().equals(boundKey)) return keyBinding;
        }
        return null;
    }
}

==> inventive-inventory-1.3.4-sources.jar: net/inventive_mods/inventive_inventory/keys/KeyRegistry.java <==
package net.inventive_mods.inventive_inventory.keys;

import net.fabricmc.fabric.api.client.keybinding.v1.KeyBindingHelper;
import net.inventive_mods.inventive_inventory.InventiveInventory;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import org.jetbrains.annotations.Nullable;

public class KeyRegistry {
    public static final class_304.class_11900 INVENTIVE_INVENTORY_CATEGORY = class_304.class_11900.method_74698(class_2960.method_60655(InventiveInventory.MOD_ID, "main"));
    public static final class_304.class_11900 INVENTIVE_INVENTORY_PROFILES_CATEGORY = class_304.class_11900.method_74698(class_2960.method_60655(InventiveInventory.MOD_ID, "profiles"));
    public static final class_304[] profileKeys = new class_304[3];
    private static final String KEY_SORT = "key.inventive_inventory.sort";
    private static final String KEY_ADVANCED_OPERATION = "key.inventive_inventory.advanced_operation";
    private static final String KEY_OPEN_PROFILES_SCREEN = "key.inventive_inventory.open_profiles_screen";
    private static final String KEY_LOAD_PROFILE = "key.inventive_inventory.load_profile";
    public static class_304 sortKey;
    public static class_304 advancedOperationKey;
    public static class_304 openProfilesScreenKey;
    public static class_304 loadProfileKey;

    public static void register() {
        sortKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_SORT,
                class_3675.class_307.field_1668,
                class_3675.field_31907,
                INVENTIVE_INVENTORY_CATEGORY
        ));
        advancedOperationKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_ADVANCED_OPERATION,
                class_3675.class_307.field_1668,
                class_3675.field_31949,
                INVENTIVE_INVENTORY_CATEGORY
        ));
        openProfilesScreenKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_OPEN_PROFILES_SCREEN,
                class_3675.class_307.field_1668,
                class_3675.field_31911,
                INVENTIVE_INVENTORY_PROFILES_CATEGORY
        ));
        loadProfileKey = KeyBindingHelper.registerKeyBinding(new class_304(
                KEY_LOAD_PROFILE,
                class_3675.class_307.field_1668,
                class_3675.field_31949,
                INVENTIVE_INVENTORY_PROFILES_CATEGORY
        ));
        for (int i = 0; i < profileKeys.length; i++) {
            profileKeys[i] = KeyBindingHelper.registerKeyBinding(new class_304(
                    "key.inventive_inventory.profile_" + i,
                    class_3675.class_307.field_1668,
                    class_3675.field_31985 + i,
                    INVENTIVE_INVENTORY_PROFILES_CATEGORY
            ));
        }
    }

    @Nullable
    public static class_304 getByTranslationKey(String translationKey) {
        for (class_304 keyBinding : InventiveInventory.getClient().field_1690.field_1839) {
            if (keyBinding.method_1431().equals(translationKey)) return keyBinding;
        }
        return null;
    }

    @Nullable
    public static class_304 getByBoundKey(String boundKey) {
        for (class_304 keyBinding : profileKeys) {
            if (keyBinding.method_16007().getString().equals(boundKey)) return keyBinding;
        }
        return null;
    }
}
